var fold_8h =
[
    [ "fold_par", "group__mfe__global__deprecated.html#ga2bc41df5d71fee6fd8da9904ee65d8fb", null ],
    [ "fold", "group__mfe__global__deprecated.html#gaadafcb0f140795ae62e5ca027e335a9b", null ],
    [ "circfold", "group__mfe__global__deprecated.html#ga4ac63ab3e8d9a80ced28b8052d94e423", null ],
    [ "free_arrays", "group__mfe__global__deprecated.html#ga107fdfe5fd641868156bfd849f6866c7", null ],
    [ "update_fold_params", "group__mfe__global__deprecated.html#ga41bf8f6fa15b94471f7095cad9f0ccf3", null ],
    [ "update_fold_params_par", "group__mfe__global__deprecated.html#gae66dc422efb8f5d56717d92d6002a9f8", null ],
    [ "export_fold_arrays", "group__mfe__global__deprecated.html#ga99641b8dbb40891da5490d3cc271e607", null ],
    [ "export_fold_arrays_par", "group__mfe__global__deprecated.html#ga6606ec0ec964ea506fdadb997a1a5328", null ],
    [ "export_circfold_arrays", "group__mfe__global__deprecated.html#ga04d5d639fd4473ca766436a9bae5665c", null ],
    [ "export_circfold_arrays_par", "group__mfe__global__deprecated.html#ga004bb901e7fd2f8d5ae68f9530318ce1", null ],
    [ "LoopEnergy", "group__mfe__global__deprecated.html#ga2163034a25c6115d894b199e97e03f6c", null ],
    [ "HairpinE", "group__mfe__global__deprecated.html#gab327ce11972f5ac069d52c8dedfdb700", null ],
    [ "initialize_fold", "group__mfe__global__deprecated.html#gac3f0a28d9cb609d388b155445073fd20", null ]
];